@@ -13,29 +13,29 @@ from pathlib import Path
 from typing import Any
 from typing import cast
 
-from ..action_base import ActionBase
-from ..action_defs import RunStdoutReturn
-from ..app_public import AppPublic
-from ..configuration_subsystem.definitions import ApplicationConfiguration
-from ..content_defs import ContentFormat
-from ..runner import Command
-from ..steps import Step
-from ..ui_framework import CursesLine
-from ..ui_framework import CursesLinePart
-from ..ui_framework import CursesLines
-from ..ui_framework import Interaction
-from ..ui_framework import nonblocking_notification
-from ..ui_framework import warning_notification
-from ..utils.functions import path_is_relative_to
-from ..utils.functions import remove_dbl_un
-from ..utils.key_value_store import KeyValueStore
-from ..utils.print import print_to_stdout
+from ansible_navigator.action_base import ActionBase
+from ansible_navigator.action_defs import RunStdoutReturn
+from ansible_navigator.app_public import AppPublic
+from ansible_navigator.configuration_subsystem.definitions import ApplicationConfiguration
+from ansible_navigator.content_defs import ContentFormat
+from ansible_navigator.runner import Command
+from ansible_navigator.steps import Step
+from ansible_navigator.ui_framework import CursesLine
+from ansible_navigator.ui_framework import CursesLinePart
+from ansible_navigator.ui_framework import CursesLines
+from ansible_navigator.ui_framework import Interaction
+from ansible_navigator.ui_framework import nonblocking_notification
+from ansible_navigator.ui_framework import warning_notification
+from ansible_navigator.utils.functions import path_is_relative_to
+from ansible_navigator.utils.functions import remove_dbl_un
+from ansible_navigator.utils.key_value_store import KeyValueStore
+from ansible_navigator.utils.print import print_to_stdout
+
 from . import _actions as actions
 from . import run_action
 
 
 def color_menu(colno: int, colname: str, entry: dict[str, Any]) -> tuple[int, int]:
-    # pylint: disable=unused-argument
     """Provide a color for a collections menu entry in one column.
 
     :param colno: The column number
@@ -188,7 +188,7 @@ class Action(ActionBase):
         ):
             msg = (
                 "Failed to create collections cache, "
-                + "Please review the ansible-navigator log file for errors."
+                "Please review the ansible-navigator log file for errors."
             )
             return RunStdoutReturn(message=msg, return_code=1)
 
@@ -199,7 +199,7 @@ class Action(ActionBase):
         if not self._collections:
             msg = (
                 "Failed to catalog collections, "
-                + "Please review the ansible-navigator log file for errors."
+                "Please review the ansible-navigator log file for errors."
             )
             return RunStdoutReturn(message=msg, return_code=1)
 
@@ -212,6 +212,14 @@ class Action(ActionBase):
         )
         return RunStdoutReturn(message="", return_code=0)
 
+    def notify_failed(self):
+        """Notify collection cataloging failed."""
+        msgs = ["humph. Something went really wrong while cataloging collections."]
+        msgs.append("Details have been added to the log file")
+        closing = ["[HINT] Please log an issue about this one, it shouldn't have happened"]
+        warning = warning_notification(messages=msgs + closing)
+        self._interaction.ui.show_form(warning)
+
     def notify_none(self):
         """Notify no collections were found."""
         msgs = ["humph. no collections were found in the following paths:"]
@@ -228,7 +236,7 @@ class Action(ActionBase):
                 paths.append(f"- {path}")
         closing = ["[HINT] Try installing some or try a different execution environment"]
         warning = warning_notification(messages=msgs + paths + closing)
-        self._interaction.ui.show(warning)
+        self._interaction.ui.show_form(warning)
 
     def _take_step(self) -> None:
         """Take a step based on the current step or step back."""
@@ -283,7 +291,7 @@ class Action(ActionBase):
 
         :returns: The plugin menu definition
         """
-        self._collection_cache.open()
+        self._collection_cache.open_()
         selected_collection = self._collections[self.steps.current.index]
         collection_name = f"__{selected_collection['known_as']}"
         collection_contents = []
@@ -361,8 +369,6 @@ class Action(ActionBase):
         )
 
     def _run_runner(self) -> None:
-        # pylint: disable=too-many-branches
-        # pylint: disable=too-many-statements
         # pylint: disable=too-many-locals
         """Use the runner subsystem to catalog collections."""
         if isinstance(self._args.set_environment_variable, dict):
@@ -487,11 +493,14 @@ class Action(ActionBase):
             kwargs,
         )
         _runner = Command(executable_cmd=python_exec_path, **kwargs)
-        output, error, _ = _runner.run()
+        output, error, ret_code = _runner.run()
 
         if error:
             msg = f"Error while running catalog collection script: {error}"
             self._logger.error(msg)
+        if ret_code:
+            self._logger.error(output)
+            self.notify_failed()
         if output:
             self._parse(output)
 
@@ -501,9 +510,8 @@ class Action(ActionBase):
         :param output: The output from the collection cataloging process
         :returns: Nothing
         """
-        # pylint: disable=too-many-branches
         # pylint: disable=too-many-locals
-        # pylint: disable=too-many-statements
+
         try:
             if not output.startswith("{"):
                 _warnings, json_str = output.split("{", 1)
@@ -552,9 +560,9 @@ class Action(ActionBase):
             collection["__version"] = collection["collection_info"].get("version", "missing")
             collection["__shadowed"] = bool(collection["hidden_by"])
             if self._args.execution_environment:
-                if collection["path"].startswith(dest_volume_mounts):
-                    collection["__type"] = "bind_mount"
-                elif collection["path"].startswith(self._adjacent_collection_dir):
+                if collection["path"].startswith(dest_volume_mounts) or collection[
+                    "path"
+                ].startswith(self._adjacent_collection_dir):
                     collection["__type"] = "bind_mount"
                 elif collection["path"].startswith(os.path.dirname(self._adjacent_collection_dir)):
                     collection["__type"] = "bind_mount"
@@ -643,7 +651,7 @@ class Action(ActionBase):
         roles_exclude_keys = ["readme"]
         self._collection_cache = cast(KeyValueStore, self._collection_cache)
 
-        self._collection_cache.open()
+        self._collection_cache.open_()
         for collection in self._collections:
             plugins_details = self._get_collection_plugins_details(collection)
 
