@@ -9,22 +9,23 @@ from copy import deepcopy
 from functools import partial
 from typing import Any
 
-from ..action_base import ActionBase
-from ..action_defs import RunStdoutReturn
-from ..app_public import AppPublic
-from ..configuration_subsystem import Constants
-from ..configuration_subsystem.definitions import ApplicationConfiguration
-from ..content_defs import ContentFormat
-from ..image_manager import inspect_all
-from ..runner import Command
-from ..steps import Step
-from ..ui_framework import CursesLine
-from ..ui_framework import CursesLinePart
-from ..ui_framework import CursesLines
-from ..ui_framework import Interaction
-from ..ui_framework import nonblocking_notification
-from ..ui_framework import warning_notification
-from ..utils.print import print_to_stdout
+from ansible_navigator.action_base import ActionBase
+from ansible_navigator.action_defs import RunStdoutReturn
+from ansible_navigator.app_public import AppPublic
+from ansible_navigator.configuration_subsystem import Constants
+from ansible_navigator.configuration_subsystem.definitions import ApplicationConfiguration
+from ansible_navigator.content_defs import ContentFormat
+from ansible_navigator.image_manager import inspect_all
+from ansible_navigator.runner import Command
+from ansible_navigator.steps import Step
+from ansible_navigator.ui_framework import CursesLine
+from ansible_navigator.ui_framework import CursesLinePart
+from ansible_navigator.ui_framework import CursesLines
+from ansible_navigator.ui_framework import Interaction
+from ansible_navigator.ui_framework import nonblocking_notification
+from ansible_navigator.ui_framework import warning_notification
+from ansible_navigator.utils.print import print_to_stdout
+
 from . import _actions as actions
 from . import run_action
 
@@ -69,7 +70,6 @@ class Action(ActionBase):
         )
 
     def color_menu(self, colno: int, colname: str, entry: dict[str, Any]) -> tuple[int, int]:
-        # pylint: disable=unused-argument
         """Provide a color for a images menu entry in one column.
 
         :param colno: The column number
@@ -566,7 +566,7 @@ class Action(ActionBase):
             kwargs.update({"container_options": self._args.container_options})
 
         self._logger.debug(
-            f"Invoke runner with executable_cmd: {python_exec_path}" + f" and kwargs: {kwargs}",
+            "Invoke runner with executable_cmd: %s and kwargs: %s", python_exec_path, kwargs
         )
         _runner = Command(executable_cmd=python_exec_path, **kwargs)
         output, error, return_code = _runner.run()
@@ -578,4 +578,4 @@ class Action(ActionBase):
         msgs.append("Details have been added to the log file")
         closing = ["[HINT] Please log an issue about this one, it shouldn't have happened"]
         warning = warning_notification(messages=msgs + closing)
-        self._interaction.ui.show(warning)
+        self._interaction.ui.show_form(warning)
