@@ -18,32 +18,33 @@ from queue import Queue
 from typing import Any
 from typing import Callable
 
-from ..action_base import ActionBase
-from ..action_defs import RunStdoutReturn
-from ..app_public import AppPublic
-from ..configuration_subsystem import to_effective
-from ..configuration_subsystem import to_sources
-from ..configuration_subsystem.definitions import ApplicationConfiguration
-from ..content_defs import ContentView
-from ..content_defs import SerializationFormat
-from ..runner import CommandAsync
-from ..steps import Step
-from ..ui_framework import CursesLine
-from ..ui_framework import CursesLinePart
-from ..ui_framework import CursesLines
-from ..ui_framework import Interaction
-from ..ui_framework import dict_to_form
-from ..ui_framework import form_to_dict
-from ..ui_framework import nonblocking_notification
-from ..ui_framework import warning_notification
-from ..utils.functions import abs_user_path
-from ..utils.functions import check_playbook_type
-from ..utils.functions import human_time
-from ..utils.functions import is_jinja
-from ..utils.functions import now_iso
-from ..utils.functions import remove_ansi
-from ..utils.functions import round_half_up
-from ..utils.serialize import serialize_write_file
+from ansible_navigator.action_base import ActionBase
+from ansible_navigator.action_defs import RunStdoutReturn
+from ansible_navigator.app_public import AppPublic
+from ansible_navigator.configuration_subsystem import to_effective
+from ansible_navigator.configuration_subsystem import to_sources
+from ansible_navigator.configuration_subsystem.definitions import ApplicationConfiguration
+from ansible_navigator.content_defs import ContentView
+from ansible_navigator.content_defs import SerializationFormat
+from ansible_navigator.runner import CommandAsync
+from ansible_navigator.steps import Step
+from ansible_navigator.ui_framework import CursesLine
+from ansible_navigator.ui_framework import CursesLinePart
+from ansible_navigator.ui_framework import CursesLines
+from ansible_navigator.ui_framework import Interaction
+from ansible_navigator.ui_framework import dict_to_form
+from ansible_navigator.ui_framework import form_to_dict
+from ansible_navigator.ui_framework import nonblocking_notification
+from ansible_navigator.ui_framework import warning_notification
+from ansible_navigator.utils.functions import abs_user_path
+from ansible_navigator.utils.functions import check_playbook_type
+from ansible_navigator.utils.functions import human_time
+from ansible_navigator.utils.functions import is_jinja
+from ansible_navigator.utils.functions import now_iso
+from ansible_navigator.utils.functions import remove_ansi
+from ansible_navigator.utils.functions import round_half_up
+from ansible_navigator.utils.serialize import serialize_write_file
+
 from . import _actions as actions
 from . import run_action
 from .stdout import Action as stdout_action
@@ -71,7 +72,6 @@ def get_color(word):
 
 
 def color_menu(_colno: int, colname: str, entry: dict[str, Any]) -> tuple[int, int]:
-    # pylint: disable=too-many-branches
     """Find matching color for word.
 
     :param colname: The column name
@@ -101,15 +101,12 @@ def color_menu(_colno: int, colname: str, entry: dict[str, Any]) -> tuple[int, i
             decoration = curses.A_BOLD
 
     elif "task" in entry:
-        if entry["__result"].lower() == "in progress":
-            color = get_color(entry["__result"])
-        elif colname in ["__result", "__host", "__number", "__task", "__task_action"]:
+        if entry["__result"].lower() == "in progress" or (
+            colname in ["__result", "__host", "__number", "__task", "__task_action"]
+        ):
             color = get_color(entry["__result"])
         elif colname == "__changed":
-            if colval is True:
-                color = 11
-            else:
-                color = get_color(entry["__result"])
+            color = 11 if colval is True else get_color(entry["__result"])
         elif colname == "__duration":
             color = 12
 
@@ -349,7 +346,6 @@ class Action(ActionBase):
         self._prepare_to_exit(interaction)
         return None
 
-    # pylint: disable=too-many-branches
     def _init_run(self) -> bool:
         """In the case of :run, check the user input.
 
@@ -490,15 +486,9 @@ class Action(ActionBase):
         """
         self._logger.debug("Inventory/Playbook not set, provided, or valid, prompting")
 
-        if isinstance(self._args.playbook, str):
-            playbook = self._args.playbook
-        else:
-            playbook = ""
+        playbook = self._args.playbook if isinstance(self._args.playbook, str) else ""
 
-        if isinstance(self._args.cmdline, list):
-            cmdline = " ".join(self._args.cmdline)
-        else:
-            cmdline = ""
+        cmdline = " ".join(self._args.cmdline) if isinstance(self._args.cmdline, list) else ""
 
         FType = dict[str, Any]
         form_dict: FType = {
@@ -573,10 +563,7 @@ class Action(ActionBase):
         """
         executable_cmd: str | None
 
-        if self.mode == "stdout_w_artifact":
-            mode = "interactive"
-        else:
-            mode = self.mode
+        mode = "interactive" if self.mode == "stdout_w_artifact" else self.mode
 
         if isinstance(self._args.set_environment_variable, dict):
             set_env_vars = {**self._args.set_environment_variable}
@@ -650,10 +637,7 @@ class Action(ActionBase):
             self._logger.debug("Drained %s events", drain_count)
 
     def _handle_message(self, message: dict) -> None:
-        # pylint: disable=too-many-branches
-        # pylint: disable=too-many-statements
         # pylint: disable=too-many-locals
-        # pylint: disable=too-many-return-statements
         """Handle a runner message.
 
         :param message: The message from runner
@@ -929,7 +913,7 @@ class Action(ActionBase):
 
             except OSError as exc:
                 error = (
-                    f"Saving the artifact file failed, resulted in the following error: f{str(exc)}"
+                    f"Saving the artifact file failed, resulted in the following error: f{exc!s}"
                 )
                 self._logger.error(error)
 
