@@ -2,11 +2,12 @@
 
 import time
 
-from ..action_base import ActionBase
-from ..app_public import AppPublic
-from ..configuration_subsystem.definitions import ApplicationConfiguration
-from ..ui_framework import Interaction
-from ..ui_framework import nonblocking_notification
+from ansible_navigator.action_base import ActionBase
+from ansible_navigator.app_public import AppPublic
+from ansible_navigator.configuration_subsystem.definitions import ApplicationConfiguration
+from ansible_navigator.ui_framework import Interaction
+from ansible_navigator.ui_framework import nonblocking_notification
+
 from . import _actions as actions
 
 
