@@ -5,13 +5,14 @@ import re
 
 from pathlib import Path
 
+from ansible_navigator.app_public import AppPublic
+from ansible_navigator.configuration_subsystem.definitions import ApplicationConfiguration
 from ansible_navigator.content_defs import ContentView
-from ..app_public import AppPublic
-from ..configuration_subsystem.definitions import ApplicationConfiguration
-from ..content_defs import SerializationFormat
-from ..ui_framework import Interaction
-from ..utils.functions import remove_dbl_un
-from ..utils.serialize import serialize_write_file
+from ansible_navigator.content_defs import SerializationFormat
+from ansible_navigator.ui_framework import Interaction
+from ansible_navigator.utils.functions import remove_dbl_un
+from ansible_navigator.utils.serialize import serialize_write_file
+
 from . import _actions as actions
 
 
@@ -29,7 +30,6 @@ class Action:
         self._args = args
         self._logger = logging.getLogger(__name__)
 
-    # pylint: disable=unused-argument
     def run(self, interaction: Interaction, app: AppPublic) -> None:
         """Execute the ``:write`` request for mode interactive.
 
@@ -37,7 +37,6 @@ class Action:
         :param app: The app instance
         :returns: Nothing
         """
-        # pylint: disable=too-many-branches
         self._logger.debug("write requested as %s", interaction.action.value)
         match = interaction.action.match.groupdict()
         filename = os.path.abspath(match["filename"])
