@@ -7,16 +7,17 @@ import os
 
 from copy import deepcopy
 
-from ..utils.definitions import ExitMessage
-from ..utils.definitions import ExitPrefix
-from ..utils.definitions import LogMessage
-from ..utils.functions import oxfordcomma
-from ..utils.functions import shlex_join
-from ..utils.json_schema import validate
-from ..utils.serialize import SafeLoader
-from ..utils.serialize import yaml
-from ..utils.version_migration.migrate import MigrationType
-from ..utils.version_migration.migrate import run_all_migrations
+from ansible_navigator.utils.definitions import ExitMessage
+from ansible_navigator.utils.definitions import ExitPrefix
+from ansible_navigator.utils.definitions import LogMessage
+from ansible_navigator.utils.functions import oxfordcomma
+from ansible_navigator.utils.functions import shlex_join
+from ansible_navigator.utils.json_schema import validate
+from ansible_navigator.utils.serialize import SafeLoader
+from ansible_navigator.utils.serialize import yaml
+from ansible_navigator.utils.version_migration.migrate import MigrationType
+from ansible_navigator.utils.version_migration.migrate import run_all_migrations
+
 from .definitions import ApplicationConfiguration
 from .definitions import Constants as C
 from .definitions import SettingsEntry
@@ -60,9 +61,11 @@ class Configurator:
         """
         if self._apply_previous_cli_entries is not C.NONE:
             if self._config.internals.initializing:
-                raise ValueError("'apply_previous_cli' cannot be used while initializing")
+                msg = "'apply_previous_cli' cannot be used while initializing"
+                raise ValueError(msg)
             if not self._config.initial:
-                raise ValueError("'apply_previous_cli' enabled prior to an initialization")
+                msg = "'apply_previous_cli' enabled prior to an initialization"
+                raise ValueError(msg)
 
     def _roll_back(self) -> None:
         """In the case of a rollback, log the configuration state prior to roll back."""
@@ -156,7 +159,6 @@ class Configurator:
 
     def _apply_settings_file(self) -> None:
         # pylint: disable=too-many-locals
-        # pylint: disable=too-many-statements
         """Apply the settings file.
 
         :raises ValueError: If the settings file is empty
@@ -179,7 +181,8 @@ class Configurator:
                     # the file will be empty, but we shouldn't exit.
                     if self._params in (["settings", "--sample"], ["settings", "--gs"]):
                         return
-                    raise ValueError("Settings file cannot be empty.")
+                    msg = "Settings file cannot be empty."
+                    raise ValueError(msg)
             except (yaml.scanner.ScannerError, yaml.parser.ParserError, ValueError) as exc:
                 exit_msg = f"Settings file found {settings_filesystem_path}, but failed to load it."
                 self._exit_messages.append(ExitMessage(message=exit_msg))
@@ -242,7 +245,7 @@ class Configurator:
                     "Errors encountered when loading settings file:"
                     f" {settings_filesystem_path}"
                     f" while loading entry {entry.name}, attempted: {settings_file_path}."
-                    f"The resulting error was {str(exc)}"
+                    f"The resulting error was {exc!s}"
                 )
                 self._exit_messages.append(ExitMessage(message=exit_msg))
                 exit_msg = (
@@ -282,10 +285,18 @@ class Configurator:
         """Apply the cli params."""
         parser = Parser(self._config).parser
         setattr(parser, "error", self._argparse_error_handler)
-        parser_response = parser.parse_known_args(self._params)
+        try:
+            # split the _params on double-dash
+            index = self._params.index("--")
+            before, after = self._params[:index], self._params[index + 1 :]
+        except ValueError:
+            before, after = self._params, []
+
+        parser_response = parser.parse_known_args(before)
         if parser_response is None:
             return
-        args, cmdline = parser_response
+        args, unknown = parser_response
+        cmdline = unknown + after
         if cmdline:
             # In the case a subcommand is not a positional, remove the --
             additional_args = [arg for arg in cmdline if arg != "--"]
@@ -344,18 +355,16 @@ class Configurator:
         :param value: The value to check.
         :return: True if the value is invalid and an error message was logged.
         """
-        if entry.cli_parameters and entry.choices:
-            if value not in entry.choices:
-                self._exit_messages.append(ExitMessage(message=entry.invalid_choice))
-                choices = [
-                    f"{entry.cli_parameters.short} {str(choice).lower()}"
-                    for choice in entry.choices
-                ]
-                exit_msg = f"Try again with {oxfordcomma(choices, 'or')}"
-                self._exit_messages.append(
-                    ExitMessage(message=exit_msg, prefix=ExitPrefix.HINT),
-                )
-                return True
+        if entry.cli_parameters and entry.choices and value not in entry.choices:
+            self._exit_messages.append(ExitMessage(message=entry.invalid_choice))
+            choices = [
+                f"{entry.cli_parameters.short} {str(choice).lower()}" for choice in entry.choices
+            ]
+            exit_msg = f"Try again with {oxfordcomma(choices, 'or')}"
+            self._exit_messages.append(
+                ExitMessage(message=exit_msg, prefix=ExitPrefix.HINT),
+            )
+            return True
         return False
 
     def _apply_previous_cli_to_current(self) -> None:
@@ -402,9 +411,11 @@ class Configurator:
                 continue
 
             # skip if the same subcommand is required for reapplication
-            if current_entry.apply_to_subsequent_cli is C.SAME_SUBCOMMAND:
-                if current_subcommand != previous_subcommand:
-                    continue
+            if (
+                current_entry.apply_to_subsequent_cli is C.SAME_SUBCOMMAND
+                and current_subcommand != previous_subcommand
+            ):
+                continue
 
             # skip if the previous entry was not set by the CLI
             if previous_entry.value.source is not C.USER_CLI:
