@@ -8,13 +8,14 @@ from dataclasses import dataclass
 from dataclasses import field
 from pathlib import Path
 
-from ..utils.definitions import ExitMessage
-from ..utils.definitions import LogMessage
-from ..utils.functions import abs_user_path
-from ..utils.functions import generate_cache_path
-from ..utils.functions import oxfordcomma
-from ..utils.key_value_store import KeyValueStore
-from ..utils.packaged_data import ImageEntry
+from ansible_navigator.utils.definitions import ExitMessage
+from ansible_navigator.utils.definitions import LogMessage
+from ansible_navigator.utils.functions import abs_user_path
+from ansible_navigator.utils.functions import generate_cache_path
+from ansible_navigator.utils.functions import oxfordcomma
+from ansible_navigator.utils.key_value_store import KeyValueStore
+from ansible_navigator.utils.packaged_data import ImageEntry
+
 from .definitions import ApplicationConfiguration
 from .definitions import CliParameters
 from .definitions import Constants as C
@@ -36,13 +37,17 @@ PLUGIN_TYPES = (
     "callback",
     "cliconf",
     "connection",
+    "filter",
     "httpapi",
     "inventory",
+    "keyword",
     "lookup",
     "module",
     "netconf",
+    "role",
     "shell",
     "strategy",
+    "test",
     "vars",
 )
 
