@@ -95,7 +95,8 @@ class CollectionCatalog:
                 plugin_type = plugin_dir.name
                 if plugin_type == "modules":
                     plugin_type = "module"
-                filenames = plugin_dir.glob("**/*.py")
+                files = list(plugin_dir.glob("**/*.py")) + list(plugin_dir.glob("**/*.yml"))
+                filenames = (x for x in files)
                 self._process_plugin_dir(
                     plugin_type,
                     filenames,
@@ -109,7 +110,6 @@ class CollectionCatalog:
         :param collection: Details describing the collection
         """
         # pylint: disable=too-many-locals
-        # pylint: disable=too-many-statements
 
         collection_name: str = collection["known_as"]
         collection["roles"] = []
@@ -118,6 +118,8 @@ class CollectionCatalog:
             return
 
         for role_directory in roles_directory.iterdir():
+            if not role_directory.is_dir():
+                continue
             role: dict[str, str | dict[str, Any]] = {
                 "short_name": role_directory.name,
                 "full_name": f"{collection_name}.{role_directory.name}",
@@ -378,8 +380,8 @@ def worker(pending_queue: multiprocessing.Queue, completed_queue: multiprocessin
                     collection_name=collection_name,
                 )
 
-        except Exception as exc:  # pylint: disable=broad-except
-            err_message = f"{type(exc).__name__} (get_docstring): {str(exc)}"
+        except Exception as exc:  # noqa: BLE001
+            err_message = f"{type(exc).__name__} (get_docstring): {exc!s}"
             completed_queue.put(("error", (checksum, plugin_path, err_message)))
             continue
 
@@ -395,7 +397,7 @@ def worker(pending_queue: multiprocessing.Queue, completed_queue: multiprocessin
             }
             completed_queue.put(("plugin", (checksum, json.dumps(q_message, default=str))))
         except JSONDecodeError as exc:
-            err_message = f"{type(exc).__name__} (json_decode_doc): {str(exc)}"
+            err_message = f"{type(exc).__name__} (json_decode_doc): {exc!s}"
             completed_queue.put(("error", (checksum, plugin_path, err_message)))
 
 
@@ -426,6 +428,7 @@ def identify_missing(collections: dict, collection_cache: KeyValueStore) -> tupl
 
 
 def parse_args() -> tuple[argparse.Namespace, list[Path]]:
+    # pylint: disable=used-before-assignment
     """Parse the arguments from the command line.
 
     :returns: The parsed arguments and all directories to search
@@ -449,10 +452,7 @@ def parse_args() -> tuple[argparse.Namespace, list[Path]]:
     parsed_args = parser.parse_args()
 
     adjacent = vars(parsed_args).get("adjacent")
-    if adjacent:
-        directories = [adjacent] + parsed_args.dirs
-    else:
-        directories = parsed_args.dirs
+    directories = [adjacent] + parsed_args.dirs if adjacent else parsed_args.dirs
 
     directories.extend(reversed(sys.path))
 
@@ -548,6 +548,7 @@ def run_command(cmd: list) -> dict:
 
 def main() -> dict:
     # pylint: disable=protected-access
+    # pylint: disable=used-before-assignment
     """Run the collection catalog process.
 
     :returns: The results from the completed collection cataloging process
