@@ -81,7 +81,7 @@ class Diagnostics:
 
     # pylint: disable=too-many-instance-attributes
 
-    __WARNING__: dict[str, JSONTypes]  # pylint: disable=invalid-name
+    __WARNING__: dict[str, JSONTypes]
     basics: dict[str, JSONTypes]
     container_engines: dict[str, JSONTypes]
     execution_environment: dict[str, JSONTypes]
@@ -115,7 +115,7 @@ def register(collector: Collector):
 DIAGNOSTIC_FAILURES = 0
 
 
-class FailedCollection(Exception):
+class FailedCollectionError(Exception):
     """Exception for a failed collection."""
 
     def __init__(self, errors):
@@ -141,7 +141,7 @@ def diagnostic_runner(func):
         :param kwargs: The keyword arguments
         :returns: The result of the function with elapsed or error information
         """
-        global DIAGNOSTIC_FAILURES  # pylint: disable=global-statement
+        global DIAGNOSTIC_FAILURES
         start = datetime.datetime.now()
         color = args[0].color
         collector = func.__collector__
@@ -150,13 +150,13 @@ def diagnostic_runner(func):
             result = func(*args, **kwargs)
             duration = (datetime.datetime.now() - start).total_seconds()
             collector.finish(color=color, duration=duration)
-        except FailedCollection as error:
+        except FailedCollectionError as error:
             # A collector exception, has data
             result = error.errors
             duration = (datetime.datetime.now() - start).total_seconds()
             collector.fail(color=color, duration=duration)
             DIAGNOSTIC_FAILURES += 1
-        except Exception as error:  # pylint: disable=broad-except
+        except Exception as error:  # noqa: BLE001
             # Any other exception, has no data
             result = {"error": str(error) + "\n" + traceback.format_exc()}
             duration = (datetime.datetime.now() - start).total_seconds()
@@ -281,7 +281,7 @@ class DiagnosticsCollector:
     def _execution_environment(self) -> dict[str, JSONTypes]:
         """Add execution environment information.
 
-        :raises FailedCollection: If the collection process fails
+        :raises FailedCollectionError: If the collection process fails
         :returns: The execution environment information
         """
         if self._args.entry("container_engine").value.source is Constants.DEFAULT_CFG:
@@ -293,7 +293,7 @@ class DiagnosticsCollector:
         )
         details = {"details": details, "errors": errors, "return_code": return_code}
         if errors or not details:
-            raise FailedCollection(details)
+            raise FailedCollectionError(details)
         return details
 
     @diagnostic_runner
@@ -341,14 +341,14 @@ class DiagnosticsCollector:
     def _local_system(self) -> dict[str, JSONTypes]:
         """Add local system information.
 
-        :raises FailedCollection: If the collection process fails
+        :raises FailedCollectionError: If the collection process fails
         :returns: The local system information
         """
         results = introspect.main(serialize=False)
         if not results:
-            raise FailedCollection(results)
+            raise FailedCollectionError(results)
         if results.get("errors"):
-            raise FailedCollection(results["errors"])
+            raise FailedCollectionError(results["errors"])
         return {"details": results}
 
     @diagnostic_runner
