@@ -7,11 +7,11 @@ import subprocess
 
 from dataclasses import dataclass
 
-from ..configuration_subsystem import Constants
-from ..utils.definitions import ExitMessage
-from ..utils.definitions import ExitPrefix
-from ..utils.definitions import LogMessage
-from ..utils.functions import shlex_join
+from ansible_navigator.configuration_subsystem import Constants
+from ansible_navigator.utils.definitions import ExitMessage
+from ansible_navigator.utils.definitions import ExitPrefix
+from ansible_navigator.utils.definitions import LogMessage
+from ansible_navigator.utils.functions import shlex_join
 
 
 @dataclass(frozen=False)
@@ -117,11 +117,11 @@ class ImagePuller:
 
     def _determine_pull(self):
         """Determine if a pull is required."""
-        if self._pull_policy == "missing" and self._image_present is False:
+        if self._pull_policy == "missing" and self._image_present is False:  # noqa: SIM114
             pull = True
-        elif self._pull_policy == "always":
+        elif self._pull_policy == "always":  # noqa: SIM114
             pull = True
-        elif self._pull_policy == "tag" and self._image_tag == "latest":
+        elif self._pull_policy == "tag" and self._image_tag == "latest":  # noqa: SIM114
             pull = True
         elif self._pull_policy == "tag" and self._image_present is False:
             pull = True
