@@ -4,10 +4,10 @@ from __future__ import annotations
 import datetime
 import logging
 import os
+import zoneinfo
 
 from .configuration_subsystem import Constants
 from .configuration_subsystem.definitions import ApplicationConfiguration
-from .utils.compatibility import zoneinfo
 
 
 logger = logging.getLogger("ansible_navigator")
@@ -29,7 +29,7 @@ class Formatter(logging.Formatter):
         """Format the log timestamp.
 
         :param record: The log record
-        :param _datefmt: The optiona date format
+        :param _datefmt: The optional date format
         :returns: The timestamp
         """
         if self._time_zone == "local":
