@@ -9,7 +9,7 @@ import re
 from collections.abc import Mapping
 from collections.abc import Sequence
 from curses import ascii as curses_ascii
-from functools import lru_cache
+from functools import cache
 from math import ceil
 from math import floor
 from re import Match
@@ -19,12 +19,13 @@ from typing import Callable
 from typing import NamedTuple
 from typing import Protocol
 
-from ..content_defs import ContentFormat
-from ..content_defs import ContentType
-from ..content_defs import ContentTypeSequence
-from ..content_defs import ContentView
-from ..utils.functions import templar
-from ..utils.serialize import serialize
+from ansible_navigator.content_defs import ContentFormat
+from ansible_navigator.content_defs import ContentType
+from ansible_navigator.content_defs import ContentTypeSequence
+from ansible_navigator.content_defs import ContentView
+from ansible_navigator.utils.functions import templar
+from ansible_navigator.utils.serialize import serialize
+
 from .colorize import Colorize
 from .colorize import rgb_to_ansi
 from .curses_defs import CursesLine
@@ -287,11 +288,8 @@ class UserInterface(CursesWindow):
         :param key_dict: the keys and their description
         :returns: The footer line
         """
-        column_widths = [len(f"{str(k)}: {str(v)}") for k, v in key_dict.items()]
-        if self._status:
-            status_width = self._progress_bar_width
-        else:
-            status_width = 0
+        column_widths = [len(f"{k!s}: {v!s}") for k, v in key_dict.items()]
+        status_width = self._progress_bar_width if self._status else 0
         gap = floor((self._screen_width - status_width - sum(column_widths)) / len(key_dict))
         adjusted_column_widths = [c + gap for c in column_widths]
         col_starts = [0]
@@ -413,9 +411,7 @@ class UserInterface(CursesWindow):
         await_input: bool,
         count: int,
     ) -> str:
-        # pylint: disable=too-many-branches
         # pylint: disable=too-many-locals
-        # pylint: disable=too-many-statements
         """Show something on the screen.
 
         :param lines: The lines to show
@@ -524,21 +520,22 @@ class UserInterface(CursesWindow):
         :param current: the content on the screen
         :returns: The name of the action and the action to call or nothing if no match found
         """
-        if not entry.startswith("{{"):  # don't match pure template
-            if "{{" in entry and "}}" in entry:
-                if isinstance(current, Mapping):
-                    template_vars = current
-                    type_msgs = []
-                else:
-                    template_vars = {"this": current}
-                    type_msgs = ["Current content passed for templating is not a dictionary."]
-                    type_msgs.append("[HINT] Use 'this' to reference it (e.g. {{ this[0] }}")
-                errors, entry = templar(entry, template_vars)
-                if errors:
-                    msgs = ["Errors encountered while templating input"] + errors
-                    msgs.extend(type_msgs)
-                    self._show_form(warning_notification(msgs))
-                    return None, None
+        if (
+            not entry.startswith("{{") and "{{" in entry and "}}" in entry
+        ):  # don't match pure template
+            if isinstance(current, Mapping):
+                template_vars = current
+                type_msgs = []
+            else:
+                template_vars = {"this": current}
+                type_msgs = ["Current content passed for templating is not a dictionary."]
+                type_msgs.append("[HINT] Use 'this' to reference it (e.g. {{ this[0] }}")
+            errors, entry = templar(entry, template_vars)
+            if errors:
+                msgs = ["Errors encountered while templating input"] + errors
+                msgs.extend(type_msgs)
+                self._show_form(warning_notification(msgs))
+                return None, None
         for kegex in self._kegexes():
             match = kegex.kegex.match(entry)
             if match:
@@ -678,9 +675,7 @@ class UserInterface(CursesWindow):
         index: int,
         await_input: bool,
     ) -> Interaction:
-        # pylint: disable=too-many-branches
         # pylint: disable=too-many-locals
-        # pylint: disable=too-many-statements
         """Show an object on the display.
 
         :param objs: A list of one or more object
@@ -690,10 +685,7 @@ class UserInterface(CursesWindow):
         """
         heading, lines = self._filter_and_serialize(objs[index])
         while True:
-            if heading is not None:
-                heading_len = len(heading)
-            else:
-                heading_len = 0
+            heading_len = len(heading) if heading is not None else 0
             footer_len = 1
 
             if self.scroll() == 0:
@@ -709,10 +701,7 @@ class UserInterface(CursesWindow):
                 last_line_idx - (self._screen_height - 1 - heading_len - footer_len),
             )
 
-            if len(objs) > 1:
-                key_dict = {"-": "previous", "+": "next", "[0-9]": "goto"}
-            else:
-                key_dict = {}
+            key_dict = {"-": "previous", "+": "next", "[0-9]": "goto"} if len(objs) > 1 else {}
 
             line_numbers = tuple(range(first_line_idx, last_line_idx + 1))
 
@@ -785,18 +774,13 @@ class UserInterface(CursesWindow):
         :param columns: The dicts keys to check
         :returns: True if a match else False
         """
-        for key in columns:
-            if self._search_value(self.menu_filter(), obj.get(key)):
-                return True
-        return False
+        return any(self._search_value(self.menu_filter(), obj.get(key)) for key in columns)
 
     @staticmethod
-    @lru_cache(maxsize=None)
+    @cache
     def _search_value(regex: Pattern, value: str) -> Match | None:
         """Check a str against a regex.
 
-        lru_cache enabled because this is hit during resize
-
         :param regex: the compiled regex
         :param value: the string to check
         :returns: the match if made
