@@ -4,14 +4,15 @@ from __future__ import annotations
 
 from pathlib import Path
 
-from ..ansi import COLOR
-from ..ansi import IS_TTY
-from ..ansi import blank_line
-from ..ansi import info
-from ..ansi import prompt_enter
-from ..ansi import prompt_yn
-from ..ansi import success
-from ..ansi import warning
+from ansible_navigator.utils.ansi import COLOR
+from ansible_navigator.utils.ansi import IS_TTY
+from ansible_navigator.utils.ansi import blank_line
+from ansible_navigator.utils.ansi import info
+from ansible_navigator.utils.ansi import prompt_enter
+from ansible_navigator.utils.ansi import prompt_yn
+from ansible_navigator.utils.ansi import success
+from ansible_navigator.utils.ansi import warning
+
 from .definitions import MigrationType
 from .definitions import migrations
 
@@ -40,7 +41,6 @@ def run_migrations(settings_file_str: str, migration_type: MigrationType) -> Non
     :param settings_file_str: Path to the settings file
     :param migration_type: Type of migration
     """
-    # pylint: disable=too-many-branches
     migrations_to_run = [
         migration()
         for migration in migrations
